package fr.mael.jiwigo.transverse.util.preferences;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import fr.mael.jiwigo.transverse.util.Tools;

/**
   Copyright (c) 2010, Mael
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of jiwigo nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
   ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
   WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
   DISCLAIMED. IN NO EVENT SHALL Mael BE LIABLE FOR ANY
   DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
   (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
   LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 * Classe de gestion des preferences
 * @author mael
 *
 */
public class PreferencesManagement {

    /**
     * Logger
     */
    public static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory
	    .getLog(PreferencesManagement.class);

    /**
     * function that returns the path of the configuration file
     * @return
     */
    private static String getConfigFilePath() {
	return System.getProperty("user.home") + "/.jiwigo/config.xml";
    }

    public static void checkValues() {
	Document document = Tools.readFileAsDocument(getConfigFilePath());
	Element el = (Element) document.getDocumentElement().getElementsByTagName("sending_method").item(0);
	if (el == null) {
	    setValue("sending_method", "0");
	}
    }

    /**
     * Creation of the default file configuration
     * @throws IOException
     */
    public static void creerFichierParDefaut() throws IOException {

	File outFile = new File(getConfigFilePath());
	if (!outFile.exists()) {
	    StringBuffer xml = new StringBuffer();
	    xml.append("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
	    xml.append("<config>\n");
	    xml.append("	<chunk_size>0.5</chunk_size>\n");
	    xml.append("	<width_original>800</width_original>\n");
	    xml.append("	<height_original>600</height_original>\n");
	    xml.append("	<image_quality>1</image_quality>\n");
	    xml.append("	<password></password>\n");
	    xml.append("	<login></login>\n");
	    xml.append("	<url></url>\n");
	    xml.append("	<use_proxy>false</use_proxy>\n");
	    xml.append("	<url_proxy></url_proxy>\n");
	    xml.append("	<port_proxy></port_proxy>\n");
	    xml.append("	<user_proxy></user_proxy>\n");
	    xml.append("	<password_proxy></password_proxy>\n");
	    xml.append("	<sending_method>0</sending_method>\n");
	    xml.append("</config>");
	    FileWriter out = new FileWriter(outFile);
	    out.write(xml.toString());
	    out.close();
	}
    }

    /**
     * Function that returns the value of a preference
     * @param key the key of the preference
     * @return the value
     */
    public static String getValue(String key) {
	try {
	    Document document = Tools.readFileAsDocument(getConfigFilePath());
	    return Tools.getStringValueDom(document.getDocumentElement(), key);
	} catch (Exception e) {
	    LOG.error(Tools.getStackTrace(e));
	    return null;
	}
    }

    /**
     * Function that gives a value to a preference key
     * @param key the key
     * @param text the value
     */
    public static void setValue(String key, String text) {
	try {
	    Document document = Tools.readFileAsDocument(getConfigFilePath());
	    try {
		Tools.setStringValueDom(document.getDocumentElement(), key, text);
	    } catch (Exception e) {
		Element element = document.createElement(key);
		element.setTextContent(text);
		document.getDocumentElement().appendChild(element);
	    }
	    Tools.writeXmlFile(document, getConfigFilePath());
	} catch (Exception e) {
	    LOG.error(Tools.getStackTrace(e));
	}
    }

}
